@@ -185,7 +185,7 @@ class ModelResults:
         return simplified_df
 
     def most_common_words_by_group(
-        self, X, text_col_name, group_col_name, num_examples, num_times_min
+        self, X, text_col_name, group_col_name, num_examples, num_times_min, min_ngram,
     ):
         """
         Get the most commons phrases for defined groups.
@@ -199,6 +199,7 @@ class ModelResults:
             Number of text examples to include per group
         num_times_min: int
             Minimum number of times word/phrase must appear in texts
+        min_n_gram: int
 
         Returns
         --------
@@ -206,9 +207,10 @@ class ModelResults:
             Has groups, top words, and counts
 
         """
-
         cv = CountVectorizer(
-            stop_words=ENGLISH_STOP_WORDS, ngram_range=(1, 3), min_df=num_times_min
+            stop_words=ENGLISH_STOP_WORDS,
+            ngram_range=(min_ngram, 3),
+            min_df=num_times_min,
         )
         vectors = cv.fit_transform(X[text_col_name]).todense()
         words = cv.get_feature_names()
